@@ -163,7 +163,7 @@ def _compute_ohc_cpu(layers, thetao, weights, area):
     """
     ohc = []
     for layer in range(len(layers)):
-        ohc_layer = da.sum(
+        ohc_layer = da.nansum(
             _multiply_array(thetao, weights[layer]),
             axis=1
         )
@@ -171,7 +171,7 @@ def _compute_ohc_cpu(layers, thetao, weights, area):
         ohc1d_total = []
         for i, basin in enumerate(area):
             ohc_basin = _multiply_array(ohc_layer, area[basin])
-            ohc1d = np.sum(ohc_basin, axis=(1, 2))
+            ohc1d = da.nansum(ohc_basin, axis=(1, 2))
             ohc1d_total.append(ohc1d)
     return ohc, ohc1d_total
 
