@@ -23,7 +23,7 @@ class TestOhc(unittest.TestCase):
             cell_height=np.array(((1., 2.), (4., 3.)), dtype=np.float32),
             cell_top_depth=np.array(((0., 0.), (1., 2.)), dtype=np.float32)
         )
-        self.assertTrue(np.all(weights == np.zeros((2, 2), dtype=np.float32)))
+        self.assertTrue(np.all(np.isnan(weights)))
 
     def test_weights_mul_layers(self):
         weights = ohc.get_weights(
